@@ -12,44 +12,43 @@
 ##############################################################################
 """ Basic membership tool.
 
-$Id: MembershipTool.py 110655 2010-04-08 15:38:57Z tseaver $
+$Id: MembershipTool.py 110577 2010-04-07 06:33:17Z jens $
 """
+
 import logging
 from warnings import warn
 
-from AccessControl import ClassSecurityInfo
+from AccessControl.SecurityInfo import ClassSecurityInfo
 from AccessControl.requestmethod import postonly
 from AccessControl.User import nobody
 from Acquisition import aq_base
 from Acquisition import aq_inner
 from Acquisition import aq_parent
-from Globals import DTMLFile
-from Globals import InitializeClass
-from Globals import MessageDialog
-from Globals import PersistentMapping
+from App.class_init import InitializeClass
+from App.Dialogs import MessageDialog
+from App.special_dtml import DTMLFile
 from OFS.Folder import Folder
+from Persistence import PersistentMapping
 from ZODB.POSException import ConflictError
 from zope.component import getUtility
 from zope.interface import implements
 
-from exceptions import AccessControl_Unauthorized
-from exceptions import BadRequest
-from interfaces import IMembershipTool
-from interfaces import ISiteRoot
-from interfaces.portal_membership \
-        import portal_membership as z2IMembershipTool
-from permissions import AccessContentsInformation
-from permissions import ChangeLocalRoles
-from permissions import ListPortalMembers
-from permissions import ManagePortal
-from permissions import ManageUsers
-from permissions import SetOwnPassword
-from permissions import View
-from utils import _checkPermission
-from utils import _dtmldir
-from utils import _getAuthenticatedUser
-from utils import getToolByName
-from utils import UniqueObject
+from Products.CMFCore.exceptions import AccessControl_Unauthorized
+from Products.CMFCore.exceptions import BadRequest
+from Products.CMFCore.interfaces import IMembershipTool
+from Products.CMFCore.interfaces import ISiteRoot
+from Products.CMFCore.permissions import AccessContentsInformation
+from Products.CMFCore.permissions import ChangeLocalRoles
+from Products.CMFCore.permissions import ListPortalMembers
+from Products.CMFCore.permissions import ManagePortal
+from Products.CMFCore.permissions import ManageUsers
+from Products.CMFCore.permissions import SetOwnPassword
+from Products.CMFCore.permissions import View
+from Products.CMFCore.utils import _checkPermission
+from Products.CMFCore.utils import _dtmldir
+from Products.CMFCore.utils import _getAuthenticatedUser
+from Products.CMFCore.utils import getToolByName
+from Products.CMFCore.utils import UniqueObject
 
 logger = logging.getLogger('CMFCore.MembershipTool')
 
@@ -63,7 +62,6 @@ class MembershipTool(UniqueObject, Folder):
     """
 
     implements(IMembershipTool)
-    __implements__ = (z2IMembershipTool, )
 
     id = 'portal_membership'
     meta_type = 'CMF Membership Tool'
@@ -346,15 +344,11 @@ class MembershipTool(UniqueObject, Folder):
             name = user.getUserName()
             # this really does need to be the user name, and not the user id,
             # because we're dealing with authentication credentials
-            if hasattr(acl_users.aq_base, 'credentialsChanged'):
-                # Use an interface provided by LoginManager.
-                acl_users.credentialsChanged(user, name, password)
-            else:
-                p = getattr(REQUEST, '_credentials_changed_path', None)
-                if p is not None:
-                    # Use an interface provided by CookieCrumbler.
-                    change = self.restrictedTraverse(p)
-                    change(user, name, password)
+            p = getattr(REQUEST, '_credentials_changed_path', None)
+            if p is not None:
+                # Use an interface provided by CookieCrumbler.
+                change = self.restrictedTraverse(p)
+                change(user, name, password)
 
     security.declareProtected(ManageUsers, 'getMemberById')
     def getMemberById(self, id):
@@ -366,13 +360,13 @@ class MembershipTool(UniqueObject, Folder):
             user = self.wrapUser(user)
         return user
 
-    def _huntUserFolder(self, username, context):
+    def _huntUserFolder(self, member_id, context):
         """Find userfolder containing user in the hierarchy
            starting from context
         """
         uf = context.acl_users
         while uf is not None:
-            user = uf.getUserById(username)
+            user = uf.getUserById(member_id)
             if user is not None:
                 return uf
             container = aq_parent(aq_inner(uf))
@@ -380,25 +374,21 @@ class MembershipTool(UniqueObject, Folder):
             uf = getattr(parent, 'acl_users', None)
         return None
 
-    def _huntUser(self, username, context):
+    def _huntUser(self, member_id, context):
         """Find user in the hierarchy of userfolders
            starting from context
         """
-        uf = self._huntUserFolder(username, context)
+        uf = self._huntUserFolder(member_id, context)
         if uf is not None:
-            return uf.getUserById(username)
+            return uf.getUserById(member_id)
 
     def __getPUS(self):
-        # Gets something we can call getUsers() and getUserNames() on.
-        acl_users = self.acl_users
-        if hasattr(acl_users, 'getUsers'):
-            return acl_users
-        else:
-            # This hack works around the absence of getUsers() in LoginManager.
-            # Gets the PersistentUserSource object that stores our users
-            for us in acl_users.UserSourcesGroup.objectValues():
-                if us.meta_type == 'Persistent User Source':
-                    return us.__of__(acl_users)
+        """ Retrieve the nearest user folder
+        """
+        warn('__getPUS is deprecated and will be removed in CMF 2.4, '
+             'please acquire "acl_users" instead.', DeprecationWarning,
+             stacklevel=2)
+        return self.acl_users
 
     security.declareProtected(ManageUsers, 'listMemberIds')
     def listMemberIds(self):
@@ -406,14 +396,14 @@ class MembershipTool(UniqueObject, Folder):
         replaced with a set of methods for querying pieces of the
         list rather than the entire list at once.
         '''
-        user_folder = self.__getPUS()
+        user_folder = self.acl_users
         return [ x.getId() for x in user_folder.getUsers() ]
 
     security.declareProtected(ManageUsers, 'listMembers')
     def listMembers(self):
         '''Gets the list of all members.
         '''
-        return map(self.wrapUser, self.__getPUS().getUsers())
+        return map(self.wrapUser, self.acl_users.getUsers())
 
     security.declareProtected(ListPortalMembers, 'searchMembers')
     def searchMembers( self, search_param, search_term ):
@@ -455,10 +445,7 @@ class MembershipTool(UniqueObject, Folder):
                     roles.append( member_role )
                     obj.manage_setLocalRoles( member_id, roles )
 
-        if reindex:
-            # It is assumed that all objects have the method
-            # reindexObjectSecurity, which is in CMFCatalogAware and
-            # thus PortalContent and PortalFolder.
+        if reindex and hasattr(aq_base(obj), 'reindexObjectSecurity'):
             obj.reindexObjectSecurity()
 
     security.declareProtected(View, 'deleteLocalRoles')
@@ -477,7 +464,7 @@ class MembershipTool(UniqueObject, Folder):
             for subobj in obj.contentValues():
                 self.deleteLocalRoles(subobj, member_ids, 0, 1)
 
-        if reindex:
+        if reindex and hasattr(aq_base(obj), 'reindexObjectSecurity'):
             # reindexObjectSecurity is always recursive
             obj.reindexObjectSecurity()
 
@@ -486,16 +473,7 @@ class MembershipTool(UniqueObject, Folder):
         '''Adds a new member to the user folder.  Security checks will have
         already been performed.  Called by portal_registration.
         '''
-        acl_users = self.acl_users
-        if hasattr(acl_users, '_doAddUser'):
-            acl_users._doAddUser(id, password, roles, domains)
-        else:
-            # The acl_users folder is a LoginManager.  Search for a UserSource
-            # with the needed support.
-            for source in acl_users.UserSourcesGroup.objectValues():
-                if hasattr(source, 'addUser'):
-                    source.__of__(self).addUser(id, password, roles, domains)
-            raise "Can't add Member", "No supported UserSources"
+        self.acl_users._doAddUser(id, password, roles, domains)
 
         if properties is not None:
             member = self.getMemberById(id)
@@ -521,7 +499,7 @@ class MembershipTool(UniqueObject, Folder):
                     member_ids.remove(member_id)
             try:
                 acl_users.userFolderDelUsers(member_ids)
-            except (AttributeError, NotImplementedError, 'NotImplemented'):
+            except (AttributeError, NotImplementedError):
                 raise NotImplementedError('The underlying User Folder '
                                          'doesn\'t support deleting members.')
         else:
