@@ -12,16 +12,18 @@
 ##############################################################################
 """ Unit test mixin classes and layers.
 
-$Id: testing.py 110655 2010-04-08 15:38:57Z tseaver $
+$Id: testing.py 110577 2010-04-07 06:33:17Z jens $
 """
 
 from OFS.SimpleItem import SimpleItem
 from Products.Five import zcml
-from zope.app.component.hooks import setHooks
+from Testing.ZopeTestCase.layer import ZopeLite
 from zope.component import adapts
 from zope.i18n.interfaces import IUserPreferredLanguages
 from zope.interface import implements
+from zope.interface.verify import verifyClass
 from zope.publisher.interfaces.http import IHTTPRequest
+from zope.site.hooks import setHooks
 from zope.testing import testrunner
 from zope.testing.cleanup import cleanUp
 
@@ -31,20 +33,7 @@ from Products.GenericSetup.utils import BodyAdapterBase
 
 class ConformsToFolder:
 
-    def test_folder_z2interfaces(self):
-        from Interface.Verify import verifyClass
-        from webdav.WriteLockInterface import WriteLockInterface
-        from Products.CMFCore.interfaces.Dynamic \
-                import DynamicType as IDynamicType
-        from Products.CMFCore.interfaces.Folderish \
-                import Folderish as IFolderish
-
-        verifyClass(IDynamicType, self._getTargetClass())
-        verifyClass(IFolderish, self._getTargetClass())
-        verifyClass(WriteLockInterface, self._getTargetClass())
-
-    def test_folder_z3interfaces(self):
-        from zope.interface.verify import verifyClass
+    def test_folder_interfaces(self):
         from webdav.interfaces import IWriteLock
         from Products.CMFCore.interfaces import IDynamicType
         from Products.CMFCore.interfaces import IFolderish
@@ -55,30 +44,16 @@ class ConformsToFolder:
         verifyClass(IMutableMinimalDublinCore, self._getTargetClass())
         verifyClass(IWriteLock, self._getTargetClass())
 
+    def test_folder_extra_interfaces(self):
+        # in the long run this interface will become deprecated
+        from Products.CMFCore.interfaces import IOpaqueItemManager
+
+        verifyClass(IOpaqueItemManager, self._getTargetClass())
+
 
 class ConformsToContent:
 
-    def test_content_z2interfaces(self):
-        from Interface.Verify import verifyClass
-        from Products.CMFCore.interfaces.Contentish \
-                import Contentish as IContentish
-        from Products.CMFCore.interfaces.DublinCore \
-                import CatalogableDublinCore as ICatalogableDublinCore
-        from Products.CMFCore.interfaces.DublinCore \
-                import DublinCore as IDublinCore
-        from Products.CMFCore.interfaces.DublinCore \
-                import MutableDublinCore as IMutableDublinCore
-        from Products.CMFCore.interfaces.Dynamic \
-                import DynamicType as IDynamicType
-
-        verifyClass(ICatalogableDublinCore, self._getTargetClass())
-        verifyClass(IContentish, self._getTargetClass())
-        verifyClass(IDublinCore, self._getTargetClass())
-        verifyClass(IDynamicType, self._getTargetClass())
-        verifyClass(IMutableDublinCore, self._getTargetClass())
-
-    def test_content_z3interfaces(self):
-        from zope.interface.verify import verifyClass
+    def test_content_interfaces(self):
         from Products.CMFCore.interfaces import ICatalogableDublinCore
         from Products.CMFCore.interfaces import IContentish
         from Products.CMFCore.interfaces import IDublinCore
@@ -93,6 +68,16 @@ class ConformsToContent:
         verifyClass(IDynamicType, self._getTargetClass())
         verifyClass(IMutableDublinCore, self._getTargetClass())
 
+    def test_content_extra_interfaces(self):
+        # in the long run these interfaces will become deprecated
+        from Products.CMFCore.interfaces import ICatalogAware
+        from Products.CMFCore.interfaces import IOpaqueItemManager
+        from Products.CMFCore.interfaces import IWorkflowAware
+
+        verifyClass(ICatalogAware, self._getTargetClass())
+        verifyClass(IOpaqueItemManager, self._getTargetClass())
+        verifyClass(IWorkflowAware, self._getTargetClass())
+
 
 class BrowserLanguages(object):
 
@@ -106,7 +91,7 @@ class BrowserLanguages(object):
         return ('test',)
 
 
-class EventZCMLLayer:
+class EventZCMLLayer(ZopeLite):
 
     @classmethod
     def testSetUp(cls):
@@ -122,14 +107,15 @@ class EventZCMLLayer:
         cleanUp()
 
 
-class TraversingZCMLLayer:
+class TraversingZCMLLayer(ZopeLite):
 
     @classmethod
     def testSetUp(cls):
         import Products.Five
+        import zope.traversing
 
         zcml.load_config('meta.zcml', Products.Five)
-        zcml.load_config('traversing.zcml', Products.Five)
+        zcml.load_config('configure.zcml', zope.traversing)
         setHooks()
 
     @classmethod
@@ -137,14 +123,15 @@ class TraversingZCMLLayer:
         cleanUp()
 
 
-class TraversingEventZCMLLayer:
+class TraversingEventZCMLLayer(ZopeLite):
 
     @classmethod
     def testSetUp(cls):
         import Products.Five
+        import zope.traversing
 
         zcml.load_config('meta.zcml', Products.Five)
-        zcml.load_config('traversing.zcml', Products.Five)
+        zcml.load_config('configure.zcml', zope.traversing)
         zcml.load_config('event.zcml', Products.Five)
         zcml.load_config('event.zcml', Products.CMFCore)
         setHooks()
@@ -154,7 +141,7 @@ class TraversingEventZCMLLayer:
         cleanUp()
 
 
-class FunctionalZCMLLayer:
+class FunctionalZCMLLayer(ZopeLite):
 
     @classmethod
     def setUp(cls):
@@ -209,7 +196,7 @@ class DummyWorkflowBodyAdapter(BodyAdapterBase):
     body = property(BodyAdapterBase._exportBody, BodyAdapterBase._importBody)
 
 
-class ExportImportZCMLLayer:
+class ExportImportZCMLLayer(ZopeLite):
 
     @classmethod
     def testSetUp(cls):
@@ -219,6 +206,7 @@ class ExportImportZCMLLayer:
         import Products.CMFCore.exportimport
 
         zcml.load_config('meta.zcml', Products.Five)
+        zcml.load_config('meta.zcml', Products.GenericSetup)
         zcml.load_config('permissions.zcml', Products.Five)
         zcml.load_config('meta.zcml', Products.GenericSetup)
         zcml.load_config('configure.zcml', Products.GenericSetup)
@@ -232,19 +220,6 @@ class ExportImportZCMLLayer:
         cleanUp()
 
 
-# Derive from ZopeLite layer if available
-try:
-    from Testing.ZopeTestCase.layer import ZopeLite
-except ImportError:
-    pass # Zope < 2.11
-else:
-    EventZCMLLayer.__bases__ = (ZopeLite,)
-    TraversingZCMLLayer.__bases__ = (ZopeLite,)
-    TraversingEventZCMLLayer.__bases__ = (ZopeLite,)
-    FunctionalZCMLLayer.__bases__ = (ZopeLite,)
-    ExportImportZCMLLayer.__bases__ = (ZopeLite,)
-
-
 def run(test_suite):
     options = testrunner.get_options()
     options.resume_layer = None
