@@ -12,7 +12,7 @@
 ##############################################################################
 """ Unit tests for ActionInformation module.
 
-$Id: test_ActionInformation.py 110655 2010-04-08 15:38:57Z tseaver $
+$Id: test_ActionInformation.py 110577 2010-04-07 06:33:17Z jens $
 """
 
 import unittest
@@ -20,6 +20,7 @@ import Testing
 
 from OFS.Folder import manage_addFolder
 from Products.PythonScripts.PythonScript import manage_addPythonScript
+from zope.interface.verify import verifyClass
 
 from Products.CMFCore.Expression import createExprContext
 from Products.CMFCore.Expression import Expression
@@ -38,8 +39,7 @@ class ActionCategoryTests(unittest.TestCase):
 
         return ActionCategory(*args, **kw)
 
-    def test_z3interfaces(self):
-        from zope.interface.verify import verifyClass
+    def test_interfaces(self):
         from Products.CMFCore.ActionInformation import ActionCategory
         from Products.CMFCore.interfaces import IActionCategory
 
@@ -63,8 +63,7 @@ class ActionTests(unittest.TestCase):
 
         return Action(*args, **kw)
 
-    def test_z3interfaces(self):
-        from zope.interface.verify import verifyClass
+    def test_interfaces(self):
         from Products.CMFCore.ActionInformation import Action
         from Products.CMFCore.interfaces import IAction
 
@@ -73,7 +72,7 @@ class ActionTests(unittest.TestCase):
     def test_getInfoData_empty(self):
         WANTED = ( {'available': True, 'category': '', 'description': '',
                     'id': 'foo', 'icon': '', 'permissions': (), 'title': '',
-                    'url': '', 'visible': True}, [] )
+                    'url': '', 'visible': True, 'link_target': None}, [] )
         a = self._makeOne('foo')
         self.assertEqual( a.getInfoData(), WANTED )
 
@@ -85,12 +84,14 @@ class ActionTests(unittest.TestCase):
                           icon_expr='string:foo_icon',
                           available_expr='',
                           permissions=('View',),
-                          visible=False)
+                          visible=False,
+                          link_target='_top')
         WANTED = ( {'available': True, 'category': '',
                     'description': 'Foo description.',
                     'id': 'foo', 'icon': a.icon_expr_object,
                     'permissions': ('View',), 'title': 'Foo Title',
-                    'url': a.url_expr_object, 'visible': False},
+                    'url': a.url_expr_object, 'visible': False,
+                    'link_target': a.link_target },
                    ['url', 'icon'] )
         self.assertEqual( a.getInfoData(), WANTED )
 
@@ -117,6 +118,29 @@ class ActionTests(unittest.TestCase):
 
         self.failUnless('value=" Add "' in form_html)
 
+    def test_clearExprObjects(self):
+        """When a *_expr property is set, a *_expr_object attribute is
+        also set which should also be cleared when the *_expr is
+        cleared."""
+        a = self._makeOne('foo',
+                          title='Foo Title',
+                          description='Foo description.',
+                          url_expr='string:${object_url}/foo_url',
+                          icon_expr='string:foo_icon',
+                          available_expr='',
+                          permissions=('View',),
+                          visible=False,
+                          link_target='_top')
+        self.failUnless(hasattr(a, 'icon_expr_object'))
+        self.failUnless(hasattr(a, 'url_expr_object'))
+        self.failIf(hasattr(a, 'available_expr_object'))
+        a.manage_changeProperties(
+            icon_expr='', url_expr='', available_expr='')
+        self.failIf(hasattr(a, 'icon_expr_object'))
+        self.failIf(hasattr(a, 'url_expr_object'))
+        self.failIf(hasattr(a, 'available_expr_object'))
+
+
 class DummyRequest:
     def __init__(self):
         self._data = {}
@@ -136,16 +160,7 @@ class ActionInfoTests(unittest.TestCase):
 
         return ActionInfo(*args, **kw)
 
-    def test_z2interfaces(self):
-        from Interface.Verify import verifyClass
-        from Products.CMFCore.ActionInformation import ActionInfo
-        from Products.CMFCore.interfaces.portal_actions \
-                import ActionInfo as IActionInfo
-
-        verifyClass(IActionInfo, ActionInfo)
-
-    def test_z3interfaces(self):
-        from zope.interface.verify import verifyClass
+    def test_interfaces(self):
         from Products.CMFCore.ActionInformation import ActionInfo
         from Products.CMFCore.interfaces import IActionInfo
 
@@ -156,7 +171,7 @@ class ActionInfoTests(unittest.TestCase):
 
         WANTED = {'allowed': True, 'available': True, 'category': '',
                   'description': '', 'icon': '', 'id': 'foo', 'title': '',
-                  'url': '', 'visible': True}
+                  'url': '', 'visible': True, 'link_target': None}
 
         action = Action(id='foo')
         ec = None
@@ -177,7 +192,7 @@ class ActionInfoTests(unittest.TestCase):
 
         WANTED = {'allowed': True, 'available': True, 'category': 'object',
                   'description': '', 'id': 'foo', 'title': 'foo', 'url': '',
-                  'visible': True}
+                  'visible': True, 'icon': '', 'link_target': None}
 
         action = ActionInformation(id='foo')
         ec = None
@@ -187,6 +202,7 @@ class ActionInfoTests(unittest.TestCase):
         self.assertEqual( ai['title'], WANTED['title'] )
         self.assertEqual( ai['description'], WANTED['description'] )
         self.assertEqual( ai['url'], WANTED['url'] )
+        self.assertEqual( ai['icon'], WANTED['icon'] )
         self.assertEqual( ai['category'], WANTED['category'] )
         self.assertEqual( ai['visible'], WANTED['visible'] )
         self.assertEqual( ai['available'], WANTED['available'] )
@@ -195,7 +211,8 @@ class ActionInfoTests(unittest.TestCase):
 
     def test_create_from_dict(self):
         WANTED = {'allowed': True, 'available': True, 'category': 'object',
-                  'id': 'foo', 'title': 'foo', 'url': '', 'visible': True}
+                  'id': 'foo', 'title': 'foo', 'url': '', 'visible': True,
+                  'icon': '' , 'link_target': None}
 
         action = {'name': 'foo', 'url': ''}
         ec = None
@@ -204,6 +221,7 @@ class ActionInfoTests(unittest.TestCase):
         self.assertEqual( ai['id'], WANTED['id'] )
         self.assertEqual( ai['title'], WANTED['title'] )
         self.assertEqual( ai['url'], WANTED['url'] )
+        self.assertEqual( ai['icon'], WANTED['icon'] )
         self.assertEqual( ai['category'], WANTED['category'] )
         self.assertEqual( ai['visible'], WANTED['visible'] )
         self.assertEqual( ai['available'], WANTED['available'] )
@@ -225,7 +243,8 @@ class ActionInfoSecurityTests(SecurityTest):
 
     def test_create_from_dict(self):
         WANTED = {'allowed': True, 'available': True, 'category': 'object',
-                  'id': 'foo', 'title': 'foo', 'url': '', 'visible': True}
+                  'id': 'foo', 'title': 'foo', 'url': '', 'visible': True,
+                  'icon': '', 'link_target': None}
 
         action = {'name': 'foo', 'url': '', 'permissions': ('View',)}
         ec = createExprContext(self.site, self.site, None)
@@ -234,6 +253,7 @@ class ActionInfoSecurityTests(SecurityTest):
         self.assertEqual( ai['id'], WANTED['id'] )
         self.assertEqual( ai['title'], WANTED['title'] )
         self.assertEqual( ai['url'], WANTED['url'] )
+        self.assertEqual( ai['icon'], WANTED['icon'] )
         self.assertEqual( ai['category'], WANTED['category'] )
         self.assertEqual( ai['visible'], WANTED['visible'] )
         self.assertEqual( ai['available'], WANTED['available'] )
@@ -339,8 +359,7 @@ class ActionInformationTests(TransactionalTest):
 
         return ActionInformation(*args, **kw)
 
-    def test_z3interfaces(self):
-        from zope.interface.verify import verifyClass
+    def test_interfaces(self):
         from Products.CMFCore.ActionInformation import ActionInformation
         from Products.CMFCore.interfaces import IAction
 
@@ -429,7 +448,8 @@ class ActionInformationTests(TransactionalTest):
     def test_getInfoData_empty(self):
         WANTED = ( {'available': True, 'category': 'object',
                     'description': '', 'id': 'foo', 'permissions': (),
-                    'title': 'foo', 'url': '', 'visible': True}, [] )
+                    'title': 'foo', 'url': '', 'visible': True, 'icon': '',
+                    'link_target': None},[])
         a = self._makeOne('foo')
         self.assertEqual( a.getInfoData(), WANTED )
 
@@ -438,14 +458,18 @@ class ActionInformationTests(TransactionalTest):
                           title='Foo Title',
                           description='Foo description.',
                           action='string:${object_url}/foo_url',
+                          icon_expr='string:${object_url}/icon.gif',
                           condition='',
                           permissions=('View',),
-                          visible=False)
+                          visible=False,
+                          link_target='_top')
         WANTED = ( {'available': True, 'category': 'object',
                     'description': 'Foo description.', 'id': 'foo',
                     'permissions': ('View',), 'title': 'Foo Title',
-                    'url': a._getActionObject(), 'visible': False},
-                   ['url'] )
+                    'url': a._getActionObject(), 'visible': False,
+                    'icon': a._getIconExpressionObject(), 
+                    'link_target': a.link_target },
+                   ['url', 'icon'] )
         self.assertEqual( a.getInfoData(), WANTED )
 
 
